@@ -1,9 +1,11 @@
 from .arrow import ArrowMaterializer
 from .base import FormulaMaterializer
 from .pandas import PandasMaterializer
+from .types import NAAction
 
 __all__ = [
     'ArrowMaterializer',
     'FormulaMaterializer',
-    'PandasMaterializer'
+    'NAAction',
+    'PandasMaterializer',
 ]
